from . import LOG_CONFIG
import logging
from logging.config import dictConfig
class Logger:

    name = "Logger"
    def __init__(self, **kwargs):
        if "name" in kwargs:
            self.name = kwargs["name"]
        pass
    
    def config_logger(self):
        dictConfig(LOG_CONFIG)
        self.logger = logging.getLogger(self.name)
    
    
    def debug(self, msg, *args, **kwargs):
        self.logger.debug(msg, *args, **kwargs)

    def info(self, msg, *args, **kwargs):
        self.logger.info(msg, *args, **kwargs)

    def warning(self, msg, *args, **kwargs):
        self.logger.warning(msg, *args, **kwargs)

    def error(self, msg, *args, **kwargs):
        self.logger.error(msg, *args, **kwargs)

    def critical(self, msg, *args, **kwargs):
        self.logger.critical(msg, *args, **kwargs)


from .logger import Logger as Logger
LOG_LEVELS = {
    "DEBUG": 1,
    "INFO": 2,
    "WARNING": 3,
    "CRITICAL": 4,
    "ERROR": 5
}

LOG_CONFIG = {
    "version": 1,
    "root": {
        "handlers": ["console", "fileHandler", "fileErrorHandler"],
    },
    "handlers":{
        "console":{
            "formatter": "std_out",
            "class": "logging.StreamHandler",
            "level": "DEBUG"
        },
        "console":{
            "formatter": "std_out",
            "class": "handlers.TimedRotatingFileHandler",
            "level": "DEBUG"
        },
        "console":{
            "formatter": "std_out",
            "class": "handlers.TimedRotatingFileHandler",
            "level": "ERROR"
        }
    },
    "formatters":{
        "std_out": {
            "format": "%(asctime)s : %(levelname)s : %(module)s : %(funcName)s : %(lineno)d : (Process Details : (%(process)d, %(processName)s), Thread Details : (%(thread)d, %(threadName)s))\nLog : %(message)s",
            "datefmt":"%d-%m-%Y %I:%M:%S"
        }
    }
}